@@ -73,6 +73,9 @@ def createDocument():
     style.textProps.size=26
     stylesheet.ParagraphStyles.append(ParagraphStyle("Heading 5",
         style.Copy(), ParagraphPropertySet(space_before=240, space_after=60)))
+    style.textProps.size=24
+    stylesheet.ParagraphStyles.append(ParagraphStyle("Heading 6",
+        style.Copy(), ParagraphPropertySet(space_before=240, space_after=60)))
 
     stylesheet.ParagraphStyles.append(ParagraphStyle("Measure Heading",
         style.Copy(), ParagraphPropertySet(space_before=60, space_after=20)))
@@ -82,6 +85,11 @@ def createDocument():
     return document
 
 
+def HtmlToRtf(markup):
+    text=htmllaundry.StripMarkup(markup)
+    text=text.replace("&#13", "\n")
+    return text
+
 
 def createSection(document, survey, request):
     t=lambda txt: translate(txt, context=request)
@@ -266,6 +274,7 @@ class IdentificationReportDownload(grok.View):
                 1:  document.StyleSheet.ParagraphStyles.Heading3,
                 2:  document.StyleSheet.ParagraphStyles.Heading4,
                 3:  document.StyleSheet.ParagraphStyles.Heading5,
+                4:  document.StyleSheet.ParagraphStyles.Heading6,
                 }
 
         for node in self.getNodes():
@@ -278,12 +287,12 @@ class IdentificationReportDownload(grok.View):
             if node.identification=="no" and not (
                     zodb_node.problem_description and zodb_node.problem_description.strip()):
                 section.append(Paragraph(warning_style,
-                    t(_("warn_risk_present", default=u"You responded negative to the above statement."))))
+                    t(_("warn_risk_present", default=u"You responded negatively to the above statement."))))
             elif node.postponed or not node.identification:
                 section.append(Paragraph(warning_style,
                     t(_("risk_unanswered", default=u"This risk still needs to be inventorised."))))
 
-            section.append(Paragraph(normal_style, htmllaundry.StripMarkup(zodb_node.description)))
+            section.append(Paragraph(normal_style, HtmlToRtf(zodb_node.description)))
 
             if node.comment and node.comment.strip():
                 section.append(Paragraph(comment_style, node.comment))
@@ -491,6 +500,7 @@ class ActionPlanReportDownload(grok.View):
                 1:  document.StyleSheet.ParagraphStyles.Heading3,
                 2:  document.StyleSheet.ParagraphStyles.Heading4,
                 3:  document.StyleSheet.ParagraphStyles.Heading5,
+                4:  document.StyleSheet.ParagraphStyles.Heading6,
                 }
 
         for node in self.getNodes():
@@ -526,7 +536,7 @@ class ActionPlanReportDownload(grok.View):
                 section.append(Paragraph(normal_style, 
                     t(_("report_priority", default=u"This is a ")), t(level)))
 
-            section.append(Paragraph(normal_style, htmllaundry.StripMarkup(zodb_node.description)))
+            section.append(Paragraph(normal_style, HtmlToRtf(zodb_node.description)))
             if node.comment and node.comment.strip():
                 section.append(Paragraph(comment_style, node.comment))
 
